package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class ConstantString extends Constant implements ConstantObject
{
    private int stringIndex;
    
    public ConstantString(final ConstantString c) {
        this(c.getStringIndex());
    }
    
    ConstantString(final DataInput file) throws IOException {
        this(file.readUnsignedShort());
    }
    
    public ConstantString(final int stringIndex) {
        super((byte)8);
        this.stringIndex = stringIndex;
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitConstantString(this);
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        file.writeByte(super.getTag());
        file.writeShort(this.stringIndex);
    }
    
    public String getBytes(final ConstantPool cp) {
        return (String)this.getConstantValue(cp);
    }
    
    @Override
    public Object getConstantValue(final ConstantPool cp) {
        return cp.getConstantUtf8(this.stringIndex).getBytes();
    }
    
    public int getStringIndex() {
        return this.stringIndex;
    }
    
    public void setStringIndex(final int stringIndex) {
        this.stringIndex = stringIndex;
    }
    
    @Override
    public String toString() {
        return super.toString() + "(stringIndex = " + this.stringIndex + ")";
    }
}
